DescItem

Enum DescItem 

#[non_exhaustive]
pub enum DescItem { long(i32), doub(f64), UntF(String, f64), bool(bool), TEXT(String), Err(String), Objc(Box<(String, Vec<(String, DescItem)>)>), _enum(String, String), VlLs(Vec<DescItem>), Xxx, }
PSD Class Descriptor object data. Only used by certain PSD features.

Some PSD format features use a dynamic meta-object format instead of feature-specific data encoding; that information is what this type is responsible for holding.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


long(i32)



doub(f64)



UntF(String, f64)

Float that carries unit system metadata. The string specifies the unit system. Examples of unit systems are “#Ang” and “#Pxl”.



bool(bool)



TEXT(String)



Err(String)

When rawpsd ran into an error while parsing the data that goes here: what kind of error was it?



Objc(Box<(String, Vec<(String, DescItem)>)>)

Entire sub-object.



_enum(String, String)

Enums, which are stringly typed in PSDs.



VlLs(Vec<DescItem>)

Variable-length list.



Xxx

Dummy non-data data.

Implementations

Source

impl DescItem

pub fn long(&self) -> i32

Get the given item if the enum is of that kind, otherwise panic.

pub fn doub(&self) -> f64

Get the given item if the enum is of that kind, otherwise panic.

pub fn bool(&self) -> bool

Get the given item if the enum is of that kind, otherwise panic.

pub fn _enum(&self) -> (String, String)

Get the given item if the enum is of that kind, otherwise panic.

pub fn UntF(&self) -> (String, f64)

Get the given item if the enum is of that kind, otherwise panic.

pub fn Objc(&self) -> Box<(String, Vec<(String, DescItem)>)>

Get the given item if the enum is of that kind, otherwise panic.

pub fn TEXT(&self) -> String

Get the given item if the enum is of that kind, otherwise panic.

pub fn VlLs(&self) -> Vec<DescItem>

Get the given item if the enum is of that kind, otherwise panic.